@@ -21,8 +21,10 @@ those parsers.
 '''
 
 import argparse, json, os
-from ..utils.printing import fill
+from ..utils.printing import (fill, BOLD, ENDC)
+from ..utils.pretty_print import format_table
 from ..utils.resolver import split_unescaped
+from ..utils.completer import InstanceTypesCompleter
 from ..exceptions import DXError
 
 class DXParserError(DXError):
@@ -53,14 +55,9 @@ json_arg.add_argument('--json', help='Display return value in JSON', action='sto
 stdout_args = argparse.ArgumentParser(add_help=False)
 stdout_args_gp = stdout_args.add_mutually_exclusive_group()
 stdout_args_gp.add_argument('--brief', help=fill('Display a brief version of the return value; for most commands, prints a DNAnexus ID per line', width_adjustment=-24), action='store_true')
-stdout_args_gp.add_argument('--summary', help='Display summary output (default)', action='store_true')
 stdout_args_gp.add_argument('--verbose', help='If available, displays extra verbose output',
                             action='store_true')
 
-def get_output_flag(args):
-    if not args.brief and not args.summary and not args.verbose:
-        args.summary = True
-
 parser_dataobject_args = argparse.ArgumentParser(add_help=False)
 parser_dataobject_args_gp = parser_dataobject_args.add_argument_group('metadata arguments')
 parser_dataobject_args_gp.add_argument('--visibility', choices=['hidden', 'visible'], dest='hidden', default='visible', help='Whether the object is hidden or not')
@@ -83,6 +80,30 @@ find_by_properties_and_tags_args.add_argument('--tag',
                                               help=fill('Tag to match; repeat as necessary, e.g. "--tag tag1 --tag tag2" will require both tags', width_adjustment=-24),
                                               action='append')
 
+find_executions_args = argparse.ArgumentParser()
+find_executions_args.add_argument('--id', help=fill('Show only the job tree or job containing this job ID', width_adjustment=-24))
+find_executions_args.add_argument('--name', help=fill('Restrict the search by job name (accepts wildcards "*" and "?")', width_adjustment=-24))
+find_executions_args.add_argument('--user', help=fill('Username who launched the job (use "self" to ask for your own jobs)', width_adjustment=-24))
+find_executions_args.add_argument('--project', help=fill('Project context (output project), default is current project if set', width_adjustment=-24))
+find_executions_args.add_argument('--all-projects', '--allprojects', help=fill('Extend search to all projects', width_adjustment=-24), action='store_true')
+find_executions_args.add_argument('--app', '--applet', '--executable', dest='executable', help=fill('Applet or App ID that job is running', width_adjustment=-24))
+find_executions_args.add_argument('--state', help=fill('State of the job, e.g. \"done\", \"failed\"', width_adjustment=-24))
+find_executions_args.add_argument('--origin', help=fill('Job ID of the top-level job', width_adjustment=-24)) # Redundant but might as well
+find_executions_args.add_argument('--parent', help=fill('Job ID of the parent job; implies --all-jobs', width_adjustment=-24))
+find_executions_args.add_argument('--created-after', help=fill('Date (e.g. 2012-01-01) or integer timestamp after which the job was last created (negative number means ms in the past, or use suffix s, m, h, d, w, M, y)', width_adjustment=-24))
+find_executions_args.add_argument('--created-before', help=fill('Date (e.g. 2012-01-01) or integer timestamp before which the job was last created (negative number means ms in the past, or use suffix s, m, h, d, w, M, y)', width_adjustment=-24))
+find_executions_args.add_argument('--no-subjobs', help=fill('Do not show any subjobs', width_adjustment=-24), action='store_true')
+find_executions_args.add_argument('--root-execution', '--root', help=fill('Execution ID of the top-level (user-initiated) job or analysis', width_adjustment=-24))
+find_executions_args.add_argument('-n', '--num-results', metavar='N', type=int, help=fill('Max number of results (trees or jobs, as according to the search mode) to return (default 10)', width_adjustment=-24), default=10)
+find_executions_args.add_argument('-o', '--show-outputs', help=fill('Show job outputs in results', width_adjustment=-24), action='store_true')
+
+def add_find_executions_search_gp(parser):
+    find_executions_search_gp = parser.add_argument_group('Search mode')
+    find_executions_search = find_executions_search_gp.add_mutually_exclusive_group()
+    find_executions_search.add_argument('--trees', help=fill('Show entire job trees for all matching results (default)', width_adjustment=-24), action='store_true')
+    find_executions_search.add_argument('--origin-jobs', help=fill('Search and display only top-level origin jobs', width_adjustment=-24), action='store_true')
+    find_executions_search.add_argument('--all-jobs', help=fill('Search for jobs at all depths matching the query (no tree structure shown)', width_adjustment=-24), action='store_true')
+
 def process_properties_args(args):
     # Properties
     properties = None
@@ -205,3 +226,38 @@ def process_extra_args(args):
             args.extra_args = json.loads(args.extra_args)
         except:
             raise DXParserError('Value given for --extra-args could not be parsed as JSON')
+
+exec_input_args = argparse.ArgumentParser(add_help=False)
+exec_input_args.add_argument('-i', '--input', help=fill('An input to be added using "<input name>[:<class>]=<input value>" (provide "class" if there is no input spec; it can be any job IO class, e.g. "string", "array:string", or "array"; if "class" is "array" or not specified, the value will be attempted to be parsed as JSON and is otherwise treated as a string)', width_adjustment=-24), action='append')
+exec_input_args.add_argument('-j', '--input-json', help=fill('The full input JSON (keys=input field names, values=input field values)', width_adjustment=-24))
+exec_input_args.add_argument('-f', '--input-json-file', dest='filename', help=fill('Load input JSON from FILENAME ("-" to use stdin)'))
+
+class PrintInstanceTypeHelp(argparse.Action):
+    def __call__(self, parser, namespace, values, option_string=None):
+        print "Help: Specifying instance types for " + parser.prog
+        print
+        print fill('You can either provide a single instance type to be used by all entry points, or a JSON string mapping from function names to instance types, e.g.')
+        print
+        print '    {"main": "dx_m1.large", "other_function": "dx_m1.medium"}'
+        print
+        print 'Available instance types:'
+        print
+        print format_table(InstanceTypesCompleter.instance_types.values(),
+                           column_names=InstanceTypesCompleter.instance_types.values()[0]._fields)
+        parser.exit(0)
+
+instance_type_arg = argparse.ArgumentParser(add_help=False)
+instance_type_arg.add_argument('--instance-type',
+                               metavar='INSTANCE_TYPE_OR_MAPPING',
+                               help=fill('Specify instance type(s) for jobs this executable will run; see --instance-type-help for more details', width_adjustment=-24)).completer = InstanceTypesCompleter()
+instance_type_arg.add_argument('--instance-type-help',
+                               nargs=0,
+                               help=fill('Print help for specifying instance types'),
+                               action=PrintInstanceTypeHelp)
+
+def process_instance_type_arg(args):
+    if args.instance_type and args.instance_type.strip().startswith('{'):
+        try:
+            args.instance_type = json.loads(args.instance_type)
+        except ValueError:
+            raise DXError("Error while parsing JSON value for --instance-type")
